Safe wrappers for the underling ioctls
This module is intended for making custom device abstractions. If you’re using the provided Device abstraction you
don’t have to use this module however mixing is not prohibited and should work.
Functions
- get_
axis_ count - Retrieve number of axis present. Calls
JSIOCGAXESioctl. - get_
axis_ mapping - Retrieve axes mapping. Calls
JSIOCGAXMAPioctl. - get_
button_ count - Retrieve number of buttons present. Calls
JSIOCGBUTTONSioctl. - get_
button_ mapping - Retrieve buttons mapping. Calls
JSIOCGBTNMAPioctl. - get_
correction_ values - Retrieve axes correction values. Calls
JSIOCGCORRioctl. - get_
driver_ version - Retrieve driver version. Calls
JSIOCGVERSIONioctl. - get_
event - Read an event. Calls
read. - get_
identifier - Retrieve device identifier. Calls
JSIOCGNAMEioctl. - set_
axis_ mapping - Set axes mapping. Calls
JSIOCSAXMAPioctl. - set_
button_ mapping - Set buttons mapping. Calls
JSIOCSBTNMAPioctl. - set_
correction_ values - Set axes correction values. Calls
JSIOCSCORRioctl.